CMD top-level constant

String const CMD

Coding Method Delimiter.

CMD is used as the delimiter of a string of data coded according to Standard ECMA-35 and to switch to a general level of control.

Implementation

const String CMD = '${ESC}d';