DMI top-level constant
String
const DMI
Disable Manual Input.
DMI causes the manual input facilities of a device to be disabled.
Implementation
const String DMI = '$ESC`';
Disable Manual Input.
DMI causes the manual input facilities of a device to be disabled.
const String DMI = '$ESC`';