EMI top-level constant
String
const EMI
Enable Manual Input.
EMI is used to enable the manual input facilities of a device.
Implementation
const String EMI = '${ESC}b';
Enable Manual Input.
EMI is used to enable the manual input facilities of a device.
const String EMI = '${ESC}b';