Color16 class final

Inheritance

Properties

color Colors
final
hashCode int
The hash code for this object.
no setteroverride
id String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

index(int offset, int highOffset) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
withPrefix(String prefix) Color16
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

black → const Color16
blue → const Color16
cyan → const Color16
green → const Color16
highBlack → const Color16
highBlue → const Color16
highCyan → const Color16
highGreen → const Color16
highMagenta → const Color16
highRed → const Color16
highWhite → const Color16
highYellow → const Color16
magenta → const Color16
red → const Color16
white → const Color16
yellow → const Color16