ColorRgb class final

Inheritance

Constructors

ColorRgb(int r, int g, int b)
factory

Properties

b int
no setter
g int
no setter
hashCode int
The hash code for this object.
no setteroverride
id String
no setteroverride
r int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
withPrefix(String prefix) ColorRgb
override

Operators

operator ==(Object other) bool
The equality operator.
override