toStringAsEscapeSequences method
The sequence read out as the standard reads it: [CSI 4 CUU].
Implementation
String toStringAsEscapeSequences() => string.ansiShowEscapeSequences();
The sequence read out as the standard reads it: [CSI 4 CUU].
String toStringAsEscapeSequences() => string.ansiShowEscapeSequences();