parsing library

Classes

Color
Color16
Color256
ColorRgb
Csi
CsiCommon
CsiParam
CsiParamDefault
CsiParamNumber
CsiParamNumbers
CsiPrivate
CsiUnknown
Entity
Esc
EscapeCode
EscUnknown
ExtendedColor
Match<S extends State<S>>
Matches<S extends State<S>>
An iterable collection of Match objects representing the parsed ANSI escape codes and text segments in a string.
MatchesResult<S extends State<S>>
MatchingState<S extends State<S>>
Osc
OscUnknown
Parser
A parser that processes strings containing ANSI escape codes and tracks the current Style.
ParserIterator<S extends State<S>>
Printer
A printer that processes ANSI escape codes and replaces the default text style.
RestoreCursor
SaveCursor
Sgr
SgrColorFunction
SgrDefaultFunction
SgrFunction
SgrFunctionWithCode
SgrSimpleFunction
SgrUnknownColorFunctionFromParams
SgrUnknownColorFunctionFromValues
SgrUnknownParamFunction
SgrUnknownParamsFunction
SinkPrinter
A printer that processes ANSI escape codes and writes the output to a StringSink.
Stack
Represents an active text style that tracks history via a stack.
StackedParser
A parser that processes strings containing ANSI escape codes and tracks the Stack of styles.
StackedPrinter
A printer that processes ANSI escape codes, replaces the default text style, and tracks the Stack of styles.
StackedSinkPrinter
A printer that processes ANSI escape codes, writes the output to a StringSink, and tracks the Stack of styles.
State<S extends State<S>>
The base class for tracking the state of ANSI escape codes.
Style
Represents the currently active text style.
Text
UnknownEscapeCode

Enums

BlinkStyle
Colors
ControlFunctionsC0
Control functions: elements of the C0 set.
ControlFunctionsC1
Control functions: elements of the C1 set.
ControlFunctionsSGR
SGR control functions.
ControlSequencesFunctions
Control sequences.
FrameStyle
IntensityStyle
ScriptStyle
UnderlineStyle

Functions

runZonedAnsiPrinter<R>(R run(), {Style defaultStyle = Style.defaults, void output(String s)?, bool ansiCodesEnabled = true, bool debugForTest = false}) → R
runZonedPrinter<R>(R run(), {Style defaultStyle = Style.defaults, void output(String s)?, bool ansiCodesEnabled = true, bool debugForTest = false}) → R
Runs the given function in a zone where all print statements are processed by the printer.
runZonedStackedPrinter<R>(R run(), {Style defaultStyle = Style.defaults, void output(String s)?, bool ansiCodesEnabled = true, bool debugForTest = false}) → R
Runs the given function in a zone where all print statements are processed by the stacked printer.