ControlFunctionsC1 enum
Control functions: elements of the C1 set.
See c1.
Values
- RESERVED_40 → const ControlFunctionsC1
-
Reserved: \x40
const ControlFunctionsC1('$ESC@', 'Reserved') - RESERVED_41 → const ControlFunctionsC1
-
Reserved: \x41
const ControlFunctionsC1('${ESC}A', 'Reserved') - BPH → const ControlFunctionsC1
-
See c1.BPH.
const ControlFunctionsC1(c1.BPH, 'Break Permitted Here') - NBH → const ControlFunctionsC1
-
See c1.NBH.
const ControlFunctionsC1(c1.NBH, 'No Break Here') - RESERVED_44 → const ControlFunctionsC1
-
Reserved: \x44
const ControlFunctionsC1('${ESC}D', 'Reserved') - NEL → const ControlFunctionsC1
-
See c1.NEL.
const ControlFunctionsC1(c1.NEL, 'Next Line') - SSA → const ControlFunctionsC1
-
See c1.SSA.
const ControlFunctionsC1(c1.SSA, 'Start Of Selected Area') - ESA → const ControlFunctionsC1
-
See c1.ESA.
const ControlFunctionsC1(c1.ESA, 'End Of Selected Area') - HTS → const ControlFunctionsC1
-
See c1.HTS.
const ControlFunctionsC1(c1.HTS, 'Character Tabulation Set') - HTJ → const ControlFunctionsC1
-
See c1.HTJ.
const ControlFunctionsC1(c1.HTJ, 'Character Tabulation With Justification') - VTS → const ControlFunctionsC1
-
See c1.VTS.
const ControlFunctionsC1(c1.VTS, 'Line Tabulation Set') - PLD → const ControlFunctionsC1
-
See c1.PLD.
const ControlFunctionsC1(c1.PLD, 'Partial Line Forward') - PLU → const ControlFunctionsC1
-
See c1.PLU.
const ControlFunctionsC1(c1.PLU, 'Partial Line Backward') - RI → const ControlFunctionsC1
-
See c1.RI.
const ControlFunctionsC1(c1.RI, 'Reverse Line Feed') - SS2 → const ControlFunctionsC1
-
See c1.SS2.
const ControlFunctionsC1(c1.SS2, 'Single-Shift Two') - SS3 → const ControlFunctionsC1
-
See c1.SS3.
const ControlFunctionsC1(c1.SS3, 'Single-Shift Three') - DCS → const ControlFunctionsC1
-
See c1.DCS.
const ControlFunctionsC1(c1.DCS, 'Device Control String') - PU1 → const ControlFunctionsC1
-
See c1.PU1.
const ControlFunctionsC1(c1.PU1, 'Private Use One') - PU2 → const ControlFunctionsC1
-
See c1.PU2.
const ControlFunctionsC1(c1.PU2, 'Private Use Two') - STS → const ControlFunctionsC1
-
See c1.STS.
const ControlFunctionsC1(c1.STS, 'Set Transmit State') - CCH → const ControlFunctionsC1
-
See c1.CCH.
const ControlFunctionsC1(c1.CCH, 'Cancel Character') - MW → const ControlFunctionsC1
-
See c1.MW.
const ControlFunctionsC1(c1.MW, 'Message Waiting') - SPA → const ControlFunctionsC1
-
See c1.SPA.
const ControlFunctionsC1(c1.SPA, 'Start Of Guarded Area') - EPA → const ControlFunctionsC1
-
See c1.EPA.
const ControlFunctionsC1(c1.EPA, 'End Of Guarded Area') - SOS → const ControlFunctionsC1
-
See c1.SOS.
const ControlFunctionsC1(c1.SOS, 'Start Of String') - RESERVED_59 → const ControlFunctionsC1
-
Reserved: \x59
const ControlFunctionsC1('${ESC}Y', 'Reserved') - SCI → const ControlFunctionsC1
-
See c1.SCI.
const ControlFunctionsC1(c1.SCI, 'Single Character Introducer') - CSI → const ControlFunctionsC1
-
See c1.CSI.
const ControlFunctionsC1(c1.CSI, 'Control Sequence Introducer') - ST → const ControlFunctionsC1
-
See c1.ST.
const ControlFunctionsC1(c1.ST, 'String Terminator') - OSC → const ControlFunctionsC1
-
See c1.OSC.
const ControlFunctionsC1(c1.OSC, 'Operating System Command') - PM → const ControlFunctionsC1
-
See c1.PM.
const ControlFunctionsC1(c1.PM, 'Privacy Message') - APC → const ControlFunctionsC1
-
See c1.APC.
const ControlFunctionsC1(c1.APC, 'Application Program Command')
Properties
- code → String
-
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
byCode(
String code) → ControlFunctionsC1?
Constants
-
values
→ const List<
ControlFunctionsC1> - A constant List of the values in this enum, in order of their declaration.