ControlFunctionsSGR enum

SGR control functions.

Inheritance
Available extensions

Values

reset → const ControlFunctionsSGR

See sgr.reset and sgr.RESET.

bold → const ControlFunctionsSGR

See sgr.bold and sgr.BOLD.

dim → const ControlFunctionsSGR

See sgr.dim and sgr.DIM.

italic → const ControlFunctionsSGR

See sgr.italic and sgr.ITALIC.

underline → const ControlFunctionsSGR

See sgr.underline and sgr.UNDERLINE.

See sgr.blink and sgr.BLINK.

blinkRapid → const ControlFunctionsSGR

See sgr.blinkRapid and sgr.BLINK_RAPID.

inverse → const ControlFunctionsSGR

See sgr.inverse and sgr.INVERSE.

invisible → const ControlFunctionsSGR

See sgr.invisible and sgr.INVISIBLE.

strikethrough → const ControlFunctionsSGR

See sgr.strikethrough and sgr.STRIKETHROUGH.

primaryFont → const ControlFunctionsSGR

See sgr.PRIMARY_FONT.

alternativeFont1 → const ControlFunctionsSGR

See sgr.ALT_FONT_1.

alternativeFont2 → const ControlFunctionsSGR

See sgr.ALT_FONT_2.

alternativeFont3 → const ControlFunctionsSGR

See sgr.ALT_FONT_3.

alternativeFont4 → const ControlFunctionsSGR

See sgr.ALT_FONT_4.

alternativeFont5 → const ControlFunctionsSGR

See sgr.ALT_FONT_5.

alternativeFont6 → const ControlFunctionsSGR

See sgr.ALT_FONT_6.

alternativeFont7 → const ControlFunctionsSGR

See sgr.ALT_FONT_7.

alternativeFont8 → const ControlFunctionsSGR

See sgr.ALT_FONT_8.

alternativeFont9 → const ControlFunctionsSGR

See sgr.ALT_FONT_9.

fraktur → const ControlFunctionsSGR

See sgr.FRAKTUR.

doublyUnderline → const ControlFunctionsSGR

See sgr.doublyUnderline and sgr.DOUBLY_UNDERLINE.

resetBoldAndDim → const ControlFunctionsSGR

See sgr.resetBoldAndDim and sgr.NOT_BOLD_NOT_DIM.

resetItalic → const ControlFunctionsSGR

See sgr.resetItalic and sgr.NOT_ITALIC.

resetUnderline → const ControlFunctionsSGR

See sgr.resetUnderline and sgr.NOT_UNDERLINE.

See sgr.resetBlink and sgr.NOT_BLINK.

reserved_26 → const ControlFunctionsSGR

Reserved for proportional spacing as specified in CCITT Recommendation T.61.

resetInverse → const ControlFunctionsSGR

See sgr.resetInverse and sgr.NOT_INVERSE.

resetInvisible → const ControlFunctionsSGR

See sgr.resetInvisible and sgr.NOT_INVISIBLE.

resetStrikethrough → const ControlFunctionsSGR

See sgr.resetStrikethrough and sgr.NOT_STRIKETHROUGH.

fgBlack → const ControlFunctionsSGR

See sgr.fgBlack and sgr.FG_BLACK.

fgRed → const ControlFunctionsSGR

See sgr.fgRed and sgr.FG_RED.

fgGreen → const ControlFunctionsSGR

See sgr.fgGreen and sgr.FG_GREEN.

fgYellow → const ControlFunctionsSGR

See sgr.fgYellow and sgr.FG_YELLOW.

fgBlue → const ControlFunctionsSGR

See sgr.fgBlue and sgr.FG_BLUE.

fgMagenta → const ControlFunctionsSGR

See sgr.fgMagenta and sgr.FG_MAGENTA.

fgCyan → const ControlFunctionsSGR

See sgr.fgCyan and sgr.FG_CYAN.

fgWhite → const ControlFunctionsSGR

See sgr.fgWhite and sgr.FG_WHITE.

fg → const ControlFunctionsSGR

See sgr.fg256Open, sgr.fg256Close, sgr.fg256 and sgr.FOREGROUND.

resetFg → const ControlFunctionsSGR

See sgr.resetFg and sgr.FG_DEFAULT.

bgBlack → const ControlFunctionsSGR

See sgr.bgBlack and sgr.BG_BLACK.

bgRed → const ControlFunctionsSGR

See sgr.bgRed and sgr.BG_RED.

bgGreen → const ControlFunctionsSGR

See sgr.bgGreen and sgr.BG_GREEN.

bgYellow → const ControlFunctionsSGR

See sgr.bgYellow and sgr.BG_YELLOW.

bgBlue → const ControlFunctionsSGR

See sgr.bgBlue and sgr.BG_BLUE.

bgMagenta → const ControlFunctionsSGR

See sgr.bgMagenta and sgr.BG_MAGENTA.

bgCyan → const ControlFunctionsSGR

See sgr.bgCyan and sgr.BG_CYAN.

bgWhite → const ControlFunctionsSGR

See sgr.bgWhite and sgr.BG_WHITE.

bg → const ControlFunctionsSGR

See sgr.bg256Open, sgr.bg256Close, sgr.bg256 and sgr.BACKGROUND.

resetBg → const ControlFunctionsSGR

See sgr.resetBg and sgr.BG_DEFAULT.

reserved_50 → const ControlFunctionsSGR

Reserved for cancelling the effect of the rendering aspect established by parameter value 26.

frame → const ControlFunctionsSGR

See sgr.frame and sgr.FRAME.

encircle → const ControlFunctionsSGR

See sgr.encircle and sgr.ENCIRCLE.

overline → const ControlFunctionsSGR

See sgr.overline and sgr.OVERLINE.

resetFrameAndEncircle → const ControlFunctionsSGR

See sgr.resetFrameAndEncircle and sgr.NOT_FRAME_NOT_ENCIRCLE.

resetOverline → const ControlFunctionsSGR

See sgr.resetOverline and sgr.NOT_OVERLINE.

reserved_56 → const ControlFunctionsSGR

Reserved for future standardization.

reserved_57 → const ControlFunctionsSGR

Reserved for future standardization.

underlineColor → const ControlFunctionsSGR

See sgr.underline256Open, sgr.underline256Close, sgr.underline256 and sgr.UNDERLINE_COLOR.

resetUnderlineColor → const ControlFunctionsSGR

See sgr.resetUnderlineColor and sgr.UNDERLINE_COLOR_DEFAULT.

reserved_60 → const ControlFunctionsSGR

Ideogram underline or right side line.

reserved_61 → const ControlFunctionsSGR

Ideogram double underline or double line on the right side.

reserved_62 → const ControlFunctionsSGR

Ideogram overline or left side line.

reserved_63 → const ControlFunctionsSGR

Ideogram double overline or double line on the left side.

reserved_64 → const ControlFunctionsSGR

Ideogram stress marking.

reserved_65 → const ControlFunctionsSGR

Cancels the effect of the rendition aspects established by parameter values 60 to 64.

reserved_66 → const ControlFunctionsSGR

Reserved.

reserved_67 → const ControlFunctionsSGR

Reserved.

reserved_68 → const ControlFunctionsSGR

Reserved.

reserved_69 → const ControlFunctionsSGR

Reserved.

reserved_70 → const ControlFunctionsSGR

Reserved.

reserved_71 → const ControlFunctionsSGR

Reserved.

reserved_72 → const ControlFunctionsSGR

Reserved.

superscript → const ControlFunctionsSGR

See sgr.superscript and sgr.SUPERSCRIPT.

subscript → const ControlFunctionsSGR

See sgr.subscript and sgr.SUBSCRIPT.

resetSuperAndSubscript → const ControlFunctionsSGR

See sgr.resetSuperAndSubscript and sgr.NOT_SUPER_NOT_SUBSCRIPT.

reserved_76 → const ControlFunctionsSGR

Reserved.

reserved_77 → const ControlFunctionsSGR

Reserved.

reserved_78 → const ControlFunctionsSGR

Reserved.

reserved_79 → const ControlFunctionsSGR

Reserved.

reserved_80 → const ControlFunctionsSGR

Reserved.

reserved_81 → const ControlFunctionsSGR

Reserved.

reserved_82 → const ControlFunctionsSGR

Reserved.

reserved_83 → const ControlFunctionsSGR

Reserved.

reserved_84 → const ControlFunctionsSGR

Reserved.

reserved_85 → const ControlFunctionsSGR

Reserved.

reserved_86 → const ControlFunctionsSGR

Reserved.

reserved_87 → const ControlFunctionsSGR

Reserved.

reserved_88 → const ControlFunctionsSGR

Reserved.

reserved_89 → const ControlFunctionsSGR

Reserved.

fgHighBlack → const ControlFunctionsSGR

See sgr.fgHighBlack and sgr.FG_HIGH_BLACK.

fgHighRed → const ControlFunctionsSGR

See sgr.fgHighRed and sgr.FG_HIGH_RED.

fgHighGreen → const ControlFunctionsSGR

See sgr.fgHighGreen and sgr.FG_HIGH_GREEN.

fgHighYellow → const ControlFunctionsSGR

See sgr.fgHighYellow and sgr.FG_HIGH_YELLOW.

fgHighBlue → const ControlFunctionsSGR

See sgr.fgHighBlue and sgr.FG_HIGH_BLUE.

fgHighMagenta → const ControlFunctionsSGR

See sgr.fgHighMagenta and sgr.FG_HIGH_MAGENTA.

fgHighCyan → const ControlFunctionsSGR

See sgr.fgHighCyan and sgr.FG_HIGH_CYAN.

fgHighWhite → const ControlFunctionsSGR

See sgr.fgHighWhite and sgr.FG_HIGH_WHITE.

reserved_98 → const ControlFunctionsSGR

Reserved.

reserved_99 → const ControlFunctionsSGR

Reserved.

bgHighBlack → const ControlFunctionsSGR

See sgr.bgHighBlack and sgr.BG_HIGH_BLACK.

bgHighRed → const ControlFunctionsSGR

See sgr.bgHighRed and sgr.BG_HIGH_RED.

bgHighGreen → const ControlFunctionsSGR

See sgr.bgHighGreen and sgr.BG_HIGH_GREEN.

bgHighYellow → const ControlFunctionsSGR

See sgr.bgHighYellow and sgr.BG_HIGH_YELLOW.

bgHighBlue → const ControlFunctionsSGR

See sgr.bgHighBlue and sgr.BG_HIGH_BLUE.

bgHighMagenta → const ControlFunctionsSGR

See sgr.bgHighMagenta and sgr.BG_HIGH_MAGENTA.

bgHighCyan → const ControlFunctionsSGR

See sgr.bgHighCyan and sgr.BG_HIGH_CYAN.

bgHighWhite → const ControlFunctionsSGR

See sgr.bgHighWhite and sgr.BG_HIGH_WHITE.

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
no setter
index int
A numeric identifier for the enumerated value.
no setterinherited
isUnused bool
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

byIndex(int index) ControlFunctionsSGR?

Constants

values → const List<ControlFunctionsSGR>
A constant List of the values in this enum, in order of their declaration.