INT top-level constant
String
const INT
Interrupt.
INT is used to indicate to the receiving device that the current process is to be interrupted and an agreed procedure is to be initiated.
Implementation
const String INT = '${ESC}a';