RIS top-level constant
String
const RIS
Reset to Initial State.
RIS causes a device to be reset to its initial state, that is, the state it has after it is made operational. This may imply, if applicable, clearing the screen, resetting the tabulation stops and the graphic rendition, and returning the cursor to the first position of the first line.
Implementation
const String RIS = '${ESC}c';