ControlCodeStyle enum
How a control code is to be shown where it must be seen rather than obeyed.
Values
- charCode → const ControlCodeStyle
-
The number of the byte, the way Dart writes it in a string:
\x0A. - abbr → const ControlCodeStyle
-
The name the standard gives it:
[LF]. - unicode → const ControlCodeStyle
-
The picture Unicode gives it:
␊. - escapeOrCharCode → const ControlCodeStyle
-
The way Dart writes it in a string where there is one,
\n, and the number of the byte where there is not. - escapeOrAbbr → const ControlCodeStyle
-
The way Dart writes it where there is one, and the name otherwise.
- escapeOrUnicode → const ControlCodeStyle
-
The way Dart writes it where there is one, and the picture otherwise.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ControlCodeStyle> - A constant List of the values in this enum, in order of their declaration.