EscCommon class final
One of the independent control functions, ESC Fs: RIS, LS2, DMI and
the seven others the standard allots.
- Inheritance
-
- Object
- Entity
- EscapeCode
- Esc
- EscCommon
Properties
- function → ControlFunctionsEscFs
-
The function this sequence stands for.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
What this code is called, as Parser.showControlFunctions writes it.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- string → String
-
The piece of the string this stands for, as it was written.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
toStringAsControlCodes(
) → String -
The sequence with its control codes spelt out by their abbreviations:
[ESC][where the bytes are.inherited -
toStringAsEscapeSequences(
) → String -
The sequence read out as the standard reads it:
[CSI 4 CUU].inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited