SgrColorFunction class final
A function setting one of the three colours: the foreground, the background or the underline.
- Inheritance
-
- Object
- SgrFunction
- SgrFunctionWithCode
- SgrColorFunction
Constructors
- SgrColorFunction(ControlFunctionsSGR code, ExtendedColor color)
-
The
colorthatcodesets, named after where the code sets it.
Properties
- code → ControlFunctionsSGR
-
The SGR code this function stands for.
finalinherited
- color → ExtendedColor
-
The colour set, under the name of the code that sets it.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited