reset top-level constant
String
const reset
Default rendition (implementation-defined), cancels the effect of any preceding occurrence of SGR in the data stream regardless of the setting of the GRAPHIC RENDITION COMBINATION MODE (GRCM).
See RESET.
Compatibility:
- +vscode
- +as
- +mac Terminal
- +mac iTerm2
- +mac Warp
- +mac WezTerm
- +mac Kitty
- +mac Alacritty
Implementation
const String reset = '$CSI$RESET$SGR';