ControlFunctionsC0 enum
Control functions: elements of the C0 set.
See c0.
Values
- NUL → const ControlFunctionsC0
-
See c0.NUL.
const ControlFunctionsC0(c0.NUL, null, '␀', 'Null') - SOH → const ControlFunctionsC0
-
See c0.SOH.
const ControlFunctionsC0(c0.SOH, null, '␁', 'Start Of Heading') - STX → const ControlFunctionsC0
-
See c0.STX.
const ControlFunctionsC0(c0.STX, null, '␂', 'Start Of Text') - ETX → const ControlFunctionsC0
-
See c0.ETX.
const ControlFunctionsC0(c0.ETX, null, '␃', 'End Of Text') - EOT → const ControlFunctionsC0
-
See c0.EOT.
const ControlFunctionsC0(c0.EOT, null, '␄', 'End Of Transmission') - ENQ → const ControlFunctionsC0
-
See c0.ENQ.
const ControlFunctionsC0(c0.ENQ, null, '␅', 'Enquiry') - ACK → const ControlFunctionsC0
-
See c0.ACK.
const ControlFunctionsC0(c0.ACK, null, '␆', 'Acknowledge') - BEL → const ControlFunctionsC0
-
See c0.BEL.
const ControlFunctionsC0(c0.BEL, null, '␇', 'Bell') - BS → const ControlFunctionsC0
-
See c0.BS.
const ControlFunctionsC0(c0.BS, r'\b', '␈', 'Backspace') - HT → const ControlFunctionsC0
-
See c0.HT.
const ControlFunctionsC0(c0.HT, r'\t', '␉', 'Horizontal Tabulation') - LF → const ControlFunctionsC0
-
See c0.LF.
const ControlFunctionsC0(c0.LF, r'\n', '␊', 'Line Feed') - VT → const ControlFunctionsC0
-
See c0.VT.
const ControlFunctionsC0(c0.VT, null, '␋', 'Vertical Tabulation') - FF → const ControlFunctionsC0
-
See c0.FF.
const ControlFunctionsC0(c0.FF, r'\f', '␌', 'Form Feed') - CR → const ControlFunctionsC0
-
See c0.CR.
const ControlFunctionsC0(c0.CR, r'\r', '␍', 'Carriage Return') - SO → const ControlFunctionsC0
-
See c0.SO.
const ControlFunctionsC0(c0.SO, null, '␎', 'Shift-Out') - SI → const ControlFunctionsC0
-
See c0.SI.
const ControlFunctionsC0(c0.SI, null, '␏', 'Shift-In') - DLE → const ControlFunctionsC0
-
See c0.DLE.
const ControlFunctionsC0(c0.DLE, null, '␐', 'Data Link Escape') - DC1 → const ControlFunctionsC0
-
See c0.DC1.
const ControlFunctionsC0(c0.DC1, null, '␑', 'Device Control One') - DC2 → const ControlFunctionsC0
-
See c0.DC2.
const ControlFunctionsC0(c0.DC2, null, '␒', 'Device Control Two') - DC3 → const ControlFunctionsC0
-
See c0.DC3.
const ControlFunctionsC0(c0.DC3, null, '␓', 'Device Control Three') - DC4 → const ControlFunctionsC0
-
See c0.DC4.
const ControlFunctionsC0(c0.DC4, null, '␔', 'Device Control Four') - NAK → const ControlFunctionsC0
-
See c0.NAK.
const ControlFunctionsC0(c0.NAK, null, '␕', '') - SYN → const ControlFunctionsC0
-
See c0.SYN.
const ControlFunctionsC0(c0.SYN, null, '␖', 'Synchronous Idle') - ETB → const ControlFunctionsC0
-
See c0.ETB.
const ControlFunctionsC0(c0.ETB, null, '␗', 'End Of Transmission Block') - CAN → const ControlFunctionsC0
-
See c0.CAN.
const ControlFunctionsC0(c0.CAN, null, '␘', 'Cancel') - EM → const ControlFunctionsC0
-
See c0.EM.
const ControlFunctionsC0(c0.EM, null, '␙', 'End Of Medium') - SUB → const ControlFunctionsC0
-
See c0.SUB.
const ControlFunctionsC0(c0.SUB, null, '␚', 'Substitute') - ESC → const ControlFunctionsC0
-
See c0.ESC.
const ControlFunctionsC0(c0.ESC, null, '␛', 'Escape') - FS → const ControlFunctionsC0
-
See c0.FS.
const ControlFunctionsC0(c0.FS, null, '␜', 'File Separator') - GS → const ControlFunctionsC0
-
See c0.GS.
const ControlFunctionsC0(c0.GS, null, '␝', 'Group Separator') - RS → const ControlFunctionsC0
-
See c0.RS.
const ControlFunctionsC0(c0.RS, null, '␞', 'Record Separator') - US → const ControlFunctionsC0
-
See c0.US.
const ControlFunctionsC0(c0.US, null, '␟', 'Unit Separator')
Properties
- code → String
-
final
- description → String
-
final
- escapeSymbol → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unicodeSymbol → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
byCode(
String code) → ControlFunctionsC0? -
byIndex(
int index) → ControlFunctionsC0?
Constants
-
values
→ const List<
ControlFunctionsC0> - A constant List of the values in this enum, in order of their declaration.